@@ -153,6 +153,11 @@ class AddNodesRequest(RpcRequest):
 
 	def set_Sync(self, Sync):  # Boolean
 		self.add_query_param('Sync', Sync)
+	def get_NetworkInterfaceTrafficMode(self): # String
+		return self.get_query_params().get('NetworkInterfaceTrafficMode')
+
+	def set_NetworkInterfaceTrafficMode(self, NetworkInterfaceTrafficMode):  # String
+		self.add_query_param('NetworkInterfaceTrafficMode', NetworkInterfaceTrafficMode)
 	def get_VSwitchId(self): # String
 		return self.get_query_params().get('VSwitchId')
 
