@@ -25,26 +25,24 @@ class ListPreferredEcsTypesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ListPreferredEcsTypes')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SpotStrategy(self):
+	def get_SpotStrategy(self): # String
 		return self.get_query_params().get('SpotStrategy')
 
-	def set_SpotStrategy(self,SpotStrategy):
-		self.add_query_param('SpotStrategy',SpotStrategy)
-
-	def get_ZoneId(self):
+	def set_SpotStrategy(self, SpotStrategy):  # String
+		self.add_query_param('SpotStrategy', SpotStrategy)
+	def get_ZoneId(self): # String
 		return self.get_query_params().get('ZoneId')
 
-	def set_ZoneId(self,ZoneId):
-		self.add_query_param('ZoneId',ZoneId)
-
-	def get_InstanceChargeType(self):
+	def set_ZoneId(self, ZoneId):  # String
+		self.add_query_param('ZoneId', ZoneId)
+	def get_InstanceChargeType(self): # String
 		return self.get_query_params().get('InstanceChargeType')
 
-	def set_InstanceChargeType(self,InstanceChargeType):
-		self.add_query_param('InstanceChargeType',InstanceChargeType)
\ No newline at end of file
+	def set_InstanceChargeType(self, InstanceChargeType):  # String
+		self.add_query_param('InstanceChargeType', InstanceChargeType)
