@@ -25,28 +25,26 @@ class SetQueueRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'SetQueue')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_QueueName(self):
+	def get_QueueName(self): # String
 		return self.get_query_params().get('QueueName')
 
-	def set_QueueName(self,QueueName):
-		self.add_query_param('QueueName',QueueName)
-
-	def get_ClusterId(self):
+	def set_QueueName(self, QueueName):  # String
+		self.add_query_param('QueueName', QueueName)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_Nodes(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_Nodes(self): # RepeatList
 		return self.get_query_params().get('Node')
 
-	def set_Nodes(self, Nodes):
-		for depth1 in range(len(Nodes)):
-			if Nodes[depth1].get('Name') is not None:
-				self.add_query_param('Node.' + str(depth1 + 1) + '.Name', Nodes[depth1].get('Name'))
\ No newline at end of file
+	def set_Nodes(self, Node):  # RepeatList
+		for depth1 in range(len(Node)):
+			if Node[depth1].get('Name') is not None:
+				self.add_query_param('Node.' + str(depth1 + 1) + '.Name', Node[depth1].get('Name'))
